package paulscode.sound.codecs;

import com.jcraft.jogg.Packet;
import com.jcraft.jogg.Page;
import com.jcraft.jogg.StreamState;
import com.jcraft.jogg.SyncState;
import com.jcraft.jorbis.Block;
import com.jcraft.jorbis.Comment;
import com.jcraft.jorbis.DspState;
import com.jcraft.jorbis.Info;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.net.UnknownServiceException;
import java.nio.ByteOrder;
import javax.sound.sampled.AudioFormat;
import paulscode.sound.ICodec;
import paulscode.sound.SoundBuffer;
import paulscode.sound.SoundSystemConfig;
import paulscode.sound.SoundSystemLogger;

/* loaded from: paulscode_sound_codecs.jar:paulscode/sound/codecs/CodecJOrbis.class */
public class CodecJOrbis implements ICodec {
    private static final boolean GET = false;
    private static final boolean SET = true;
    private static final boolean XXX = false;
    protected URL url;
    private InputStream inputStream;
    private AudioFormat audioFormat;
    private int bufferSize;
    private int convertedBufferSize;
    private float[][][] pcmInfo;
    private int[] pcmIndex;
    private static final boolean LITTLE_ENDIAN;
    protected URLConnection urlConnection = null;
    private boolean endOfStream = false;
    private boolean initialized = false;
    private byte[] buffer = null;
    private int count = 0;
    private int index = 0;
    private Packet joggPacket = new Packet();
    private Page joggPage = new Page();
    private StreamState joggStreamState = new StreamState();
    private SyncState joggSyncState = new SyncState();
    private DspState jorbisDspState = new DspState();
    private Block jorbisBlock = new Block(this.jorbisDspState);
    private Comment jorbisComment = new Comment();
    private Info jorbisInfo = new Info();
    private SoundSystemLogger logger = SoundSystemConfig.getLogger();

    static {
        LITTLE_ENDIAN = ByteOrder.nativeOrder() == ByteOrder.LITTLE_ENDIAN;
    }

    public void reverseByteOrder(boolean z) {
    }

    /* JADX WARN: Type inference failed for: r1v38, types: [float[][], float[][][]] */
    public boolean initialize(URL url) {
        initialized(true, false);
        if (this.joggStreamState != null) {
            this.joggStreamState.clear();
        }
        if (this.jorbisBlock != null) {
            this.jorbisBlock.clear();
        }
        if (this.jorbisDspState != null) {
            this.jorbisDspState.clear();
        }
        if (this.jorbisInfo != null) {
            this.jorbisInfo.clear();
        }
        if (this.joggSyncState != null) {
            this.joggSyncState.clear();
        }
        if (this.inputStream != null) {
            try {
                this.inputStream.close();
            } catch (IOException e) {
            }
        }
        this.url = url;
        this.bufferSize = SoundSystemConfig.getStreamingBufferSize() / 2;
        this.buffer = null;
        this.count = 0;
        this.index = 0;
        this.joggStreamState = new StreamState();
        this.jorbisBlock = new Block(this.jorbisDspState);
        this.jorbisDspState = new DspState();
        this.jorbisInfo = new Info();
        this.joggSyncState = new SyncState();
        try {
            this.urlConnection = url.openConnection();
            if (this.urlConnection != null) {
                try {
                    this.inputStream = openInputStream();
                } catch (IOException e2) {
                    errorMessage("Unable to acquire inputstream in method 'initialize'.");
                    printStackTrace(e2);
                    cleanup();
                    return false;
                }
            }
            endOfStream(true, false);
            this.joggSyncState.init();
            this.joggSyncState.buffer(this.bufferSize);
            this.buffer = this.joggSyncState.data;
            try {
                if (!readHeader()) {
                    errorMessage("Error reading the header");
                    return false;
                }
                this.convertedBufferSize = this.bufferSize * 2;
                this.jorbisDspState.synthesis_init(this.jorbisInfo);
                this.jorbisBlock.init(this.jorbisDspState);
                this.audioFormat = new AudioFormat(this.jorbisInfo.rate, 16, this.jorbisInfo.channels, true, false);
                this.pcmInfo = new float[SET];
                this.pcmIndex = new int[this.jorbisInfo.channels];
                initialized(true, true);
                return true;
            } catch (IOException e3) {
                errorMessage("Error reading the header");
                return false;
            }
        } catch (UnknownServiceException e4) {
            errorMessage("Unable to create a UrlConnection in method 'initialize'.");
            printStackTrace(e4);
            cleanup();
            return false;
        } catch (IOException e5) {
            errorMessage("Unable to create a UrlConnection in method 'initialize'.");
            printStackTrace(e5);
            cleanup();
            return false;
        }
    }

    protected InputStream openInputStream() {
        return this.urlConnection.getInputStream();
    }

    public boolean initialized() {
        return initialized(false, false);
    }

    public SoundBuffer read() {
        byte[] readBytes = readBytes();
        if (readBytes == null) {
            return null;
        }
        return new SoundBuffer(readBytes, this.audioFormat);
    }

    public SoundBuffer readAll() {
        byte[] readBytes = readBytes();
        while (!endOfStream(false, false)) {
            readBytes = appendByteArrays(readBytes, readBytes());
            if (readBytes != null && readBytes.length >= SoundSystemConfig.getMaxFileSize()) {
                break;
            }
        }
        return new SoundBuffer(readBytes, this.audioFormat);
    }

    public boolean endOfStream() {
        return endOfStream(false, false);
    }

    public void cleanup() {
        this.joggStreamState.clear();
        this.jorbisBlock.clear();
        this.jorbisDspState.clear();
        this.jorbisInfo.clear();
        this.joggSyncState.clear();
        if (this.inputStream != null) {
            try {
                this.inputStream.close();
            } catch (IOException e) {
            }
        }
        this.joggStreamState = null;
        this.jorbisBlock = null;
        this.jorbisDspState = null;
        this.jorbisInfo = null;
        this.joggSyncState = null;
        this.inputStream = null;
    }

    public AudioFormat getAudioFormat() {
        return this.audioFormat;
    }

    private boolean readHeader() {
        int pageout;
        int packetout;
        this.index = this.joggSyncState.buffer(this.bufferSize);
        int read = this.inputStream.read(this.joggSyncState.data, this.index, this.bufferSize);
        if (read < 0) {
            read = 0;
        }
        this.joggSyncState.wrote(read);
        if (this.joggSyncState.pageout(this.joggPage) != SET) {
            if (read < this.bufferSize) {
                return true;
            }
            errorMessage("Ogg header not recognized in method 'readHeader'.");
            return false;
        }
        this.joggStreamState.init(this.joggPage.serialno());
        this.jorbisInfo.init();
        this.jorbisComment.init();
        if (this.joggStreamState.pagein(this.joggPage) < 0) {
            errorMessage("Problem with first Ogg header page in method 'readHeader'.");
            return false;
        }
        if (this.joggStreamState.packetout(this.joggPacket) != SET) {
            errorMessage("Problem with first Ogg header packet in method 'readHeader'.");
            return false;
        }
        if (this.jorbisInfo.synthesis_headerin(this.jorbisComment, this.joggPacket) < 0) {
            errorMessage("File does not contain Vorbis header in method 'readHeader'.");
            return false;
        }
        int i = 0;
        while (i < 2) {
            while (i < 2 && (pageout = this.joggSyncState.pageout(this.joggPage)) != 0) {
                if (pageout == SET) {
                    this.joggStreamState.pagein(this.joggPage);
                    while (i < 2 && (packetout = this.joggStreamState.packetout(this.joggPacket)) != 0) {
                        if (packetout == -1) {
                            errorMessage("Secondary Ogg header corrupt in method 'readHeader'.");
                            return false;
                        }
                        this.jorbisInfo.synthesis_headerin(this.jorbisComment, this.joggPacket);
                        i += SET;
                    }
                }
            }
            this.index = this.joggSyncState.buffer(this.bufferSize);
            int read2 = this.inputStream.read(this.joggSyncState.data, this.index, this.bufferSize);
            if (read2 < 0) {
                read2 = 0;
            }
            if (read2 == 0 && i < 2) {
                errorMessage("End of file reached before finished readingOgg header in method 'readHeader'");
                return false;
            }
            this.joggSyncState.wrote(read2);
        }
        this.index = this.joggSyncState.buffer(this.bufferSize);
        this.buffer = this.joggSyncState.data;
        return true;
    }

    /* JADX WARN: Code restructure failed: missing block: B:22:0x00a2, code lost:
    
        if (r6.joggPage.eos() == 0) goto L24;
     */
    /* JADX WARN: Code restructure failed: missing block: B:23:0x00a5, code lost:
    
        endOfStream(true, true);
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private byte[] readBytes() {
        /*
            Method dump skipped, instructions count: 287
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: paulscode.sound.codecs.CodecJOrbis.readBytes():byte[]");
    }

    private byte[] decodeCurrentPacket() {
        int synthesis_pcmout;
        byte[] bArr = new byte[this.convertedBufferSize];
        if (this.jorbisBlock.synthesis(this.joggPacket) == 0) {
            this.jorbisDspState.synthesis_blockin(this.jorbisBlock);
        }
        int i = this.convertedBufferSize / (this.jorbisInfo.channels * 2);
        int i2 = 0;
        while (i2 < this.convertedBufferSize && (synthesis_pcmout = this.jorbisDspState.synthesis_pcmout(this.pcmInfo, this.pcmIndex)) > 0) {
            int i3 = synthesis_pcmout < i ? synthesis_pcmout : i;
            for (int i4 = 0; i4 < this.jorbisInfo.channels; i4 += SET) {
                int i5 = i4 * 2;
                for (int i6 = 0; i6 < i3; i6 += SET) {
                    int i7 = (int) (this.pcmInfo[0][i4][this.pcmIndex[i4] + i6] * 32767.0f);
                    if (i7 > 32767) {
                        i7 = 32767;
                    }
                    if (i7 < -32768) {
                        i7 = -32768;
                    }
                    if (i7 < 0) {
                        i7 |= 32768;
                    }
                    if (LITTLE_ENDIAN) {
                        bArr[i2 + i5] = (byte) i7;
                        bArr[i2 + i5 + SET] = (byte) (i7 >>> 8);
                    } else {
                        bArr[i2 + i5 + SET] = (byte) i7;
                        bArr[i2 + i5] = (byte) (i7 >>> 8);
                    }
                    i5 += 2 * this.jorbisInfo.channels;
                }
            }
            i2 += i3 * this.jorbisInfo.channels * 2;
            this.jorbisDspState.synthesis_read(i3);
        }
        return trimArray(bArr, i2);
    }

    private synchronized boolean initialized(boolean z, boolean z2) {
        if (z == SET) {
            this.initialized = z2;
        }
        return this.initialized;
    }

    private synchronized boolean endOfStream(boolean z, boolean z2) {
        if (z == SET) {
            this.endOfStream = z2;
        }
        return this.endOfStream;
    }

    private static byte[] trimArray(byte[] bArr, int i) {
        byte[] bArr2 = null;
        if (bArr != null && bArr.length > i) {
            bArr2 = new byte[i];
            System.arraycopy(bArr, 0, bArr2, 0, i);
        }
        return bArr2;
    }

    private static byte[] appendByteArrays(byte[] bArr, byte[] bArr2) {
        byte[] bArr3;
        if (bArr == null && bArr2 == null) {
            return null;
        }
        if (bArr == null) {
            bArr3 = new byte[bArr2.length];
            System.arraycopy(bArr2, 0, bArr3, 0, bArr2.length);
        } else if (bArr2 == null) {
            bArr3 = new byte[bArr.length];
            System.arraycopy(bArr, 0, bArr3, 0, bArr.length);
        } else {
            bArr3 = new byte[bArr.length + bArr2.length];
            System.arraycopy(bArr, 0, bArr3, 0, bArr.length);
            System.arraycopy(bArr2, 0, bArr3, bArr.length, bArr2.length);
        }
        return bArr3;
    }

    private void errorMessage(String str) {
        this.logger.errorMessage("CodecJOrbis", str, 0);
    }

    private void printStackTrace(Exception exc) {
        this.logger.printStackTrace(exc, SET);
    }
}
